<!--
Copyright (C) 2023 Maxwell G <maxwell@gtmx.me>

SPDX-License-Identifier: GPL-2.0-or-later
-->

# `fedrq._archive`

!!! warning
    The `fedrq._archive` is a private, unstable API

::: fedrq._archive
